import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import AtomValidationText, { AtomValidationTextTypes } from '@s-ui/react-atom-validation-text';
import AtomLabel, { AtomLabelTypes } from '@s-ui/react-atom-label';
import AtomHelpText from '@s-ui/react-atom-help-text';
var BASE_CLASS = 'sui-MoleculeField';
var CLASS_INLINE = BASE_CLASS + "--inline";
var CLASS_INLINE_REVERSE = CLASS_INLINE + "-reverse";
var CLASS_CONTAINER = BASE_CLASS + "-inputContainer";

var MoleculeField = function MoleculeField(_ref) {
  var inline = _ref.inline,
      reverse = _ref.reverse,
      errorText = _ref.errorText,
      successText = _ref.successText,
      label = _ref.label,
      helpText = _ref.helpText,
      name = _ref.name,
      onClickLabel = _ref.onClickLabel,
      children = _ref.children;
  var className = cx(BASE_CLASS, inline && CLASS_INLINE, inline && reverse && CLASS_INLINE_REVERSE);
  var statusValidationText, typeValidationLabel, typeValidationText;

  if (errorText) {
    statusValidationText = errorText;
    typeValidationLabel = AtomLabelTypes.ERROR;
    typeValidationText = AtomValidationTextTypes.ERROR;
  }

  if (successText) {
    statusValidationText = successText;
    typeValidationLabel = AtomLabelTypes.SUCCESS;
    typeValidationText = AtomValidationTextTypes.SUCCESS;
  }

  return React.createElement("div", {
    className: className
  }, React.createElement(AtomLabel, {
    type: typeValidationLabel,
    name: name,
    text: label,
    onClick: onClickLabel
  }), React.createElement("div", {
    className: CLASS_CONTAINER
  }, children, (successText || errorText) && React.createElement(AtomValidationText, {
    type: typeValidationText,
    text: statusValidationText
  }), helpText && React.createElement(AtomHelpText, {
    text: helpText
  })));
};

MoleculeField.displayName = 'MoleculeField';
export default MoleculeField;